changeset 213:b1c9e7670850

Changed the Dragon editions to save from RAM location $EF00 - same as COCO
author roug
date Mon, 15 Jul 2002 21:48:35 +0000
parents 729ecf675c6b
children aa7dad921edd
files level1/cmds/cobbler.asm level1/cmds/cobbler_d64.asm level1/cmds/os9gen.asm level1/cmds/os9gen_d64.asm
diffstat 4 files changed, 23 insertions(+), 13 deletions(-) [+]
line wrap: on
line diff
--- a/level1/cmds/cobbler.asm	Mon Jul 15 21:34:54 2002 +0000
+++ b/level1/cmds/cobbler.asm	Mon Jul 15 21:48:35 2002 +0000
@@ -20,6 +20,8 @@
 atrv     set   ReEnt+rev
 rev      set   $01
 edition  set   5
+os9start equ  $EF00
+os9size  equ  $0F80
 
          mod   eom,name,tylg,atrv,start,size
 
@@ -231,8 +233,8 @@
          ldu   #$6400
          os9   I$Seek   Jump to LSN 612
          puls  u
-         ldx   #$EF00    Address of kernel in RAM
-         ldy   #$0F80    Amount to write
+         ldx   #os9start    Address of kernel in RAM
+         ldy   #os9size    Amount to write
          os9   I$Write  
          bcs   ETrack
          os9   I$Close  
--- a/level1/cmds/cobbler_d64.asm	Mon Jul 15 21:34:54 2002 +0000
+++ b/level1/cmds/cobbler_d64.asm	Mon Jul 15 21:48:35 2002 +0000
@@ -6,6 +6,7 @@
 * Ed.    Comments                                       Who YY/MM/DD
 * ------------------------------------------------------------------
 *   5    From Dragon OS-9 Level One VR 01.02.00
+*   6    New cobbler saves from address $EF00 instead of $F000
 
          nam   Cobbler
          ttl   Make a bootstrap file
@@ -19,7 +20,9 @@
 tylg     set   Prgrm+Objct   
 atrv     set   ReEnt+rev
 rev      set   $01
-edition  set   5
+edition  set   6
+os9start equ  $EF00
+os9size  equ  $0F80
 
          mod   eom,name,tylg,atrv,start,size
 
@@ -172,8 +175,8 @@
          anda  #$90
          eora  #$90
          bne   NotAllo
-         ldx   #$F000    Address of kernel in RAM
-         ldy   #$0F00    Amount to write
+         ldx   #os9start    Address of kernel in RAM
+         ldy   #os9size     Amount to write
          lda   <DevFd
          os9   I$Write  
          bcs   ETrack
--- a/level1/cmds/os9gen.asm	Mon Jul 15 21:34:54 2002 +0000
+++ b/level1/cmds/os9gen.asm	Mon Jul 15 21:48:35 2002 +0000
@@ -22,6 +22,8 @@
 atrv     set   ReEnt+rev
 rev      set   $01
 edition  set   7
+os9start equ  $EF00
+os9size  equ  $0F80
 
          mod   eom,name,tylg,atrv,start,size
 
@@ -399,8 +401,8 @@
          ldu   #$6400
          os9   I$Seek   
          puls  u
-         ldx   #$EF00    Address of kernel in RAM
-         ldy   #$0F80    Amount to write
+         ldx   #os9start    Address of kernel in RAM
+         ldy   #os9size     Amount to write
          os9   I$Write  
          bcs   L04FC
          os9   I$Close  
--- a/level1/cmds/os9gen_d64.asm	Mon Jul 15 21:34:54 2002 +0000
+++ b/level1/cmds/os9gen_d64.asm	Mon Jul 15 21:48:35 2002 +0000
@@ -6,14 +6,15 @@
 * Ed.    Comments                                       Who YY/MM/DD
 * ------------------------------------------------------------------
 *   7    From Dragon OS-9 Level One VR 01.02.00
+*   8    New os9gen saves from address $EF00 instead of $F000
 
-* DragonDOS BOOT loads sectors (numbered from 0) 2-17 (3840 bytes) into
+* DragonDOS BOOT loads sectors (numbered from 0) 2-17 (4096 bytes) into
 * RAM at location 9728. The first two bytes of sector 2 must be ASCII 'OS'
 * for this to work. It then jumps to 9730 and begins execution.
 *
 * The boot code switches into RAM mode, and copies the entire section to
 * $F000 and jumps to $F04F.
 * The 3840 bytes contain a few bytes to do the RAM mode switch, then
 * immediately after comes the kernel modules; OS9, OS9p2, Init and Boot
 * The rest of the bootstrap is in the OS9Boot file. The disk head at LSN0
 * contains the LSN of the bootstrap file in field DD.BT.
@@ -30,7 +31,9 @@
 tylg     set   Prgrm+Objct   
 atrv     set   ReEnt+rev
 rev      set   $01
-edition  set   7
+edition  set   8
+os9start equ  $EF00
+os9size  equ  $0F80
 
          mod   eom,name,tylg,atrv,start,size
 
@@ -275,8 +278,8 @@
          anda  #$90
          eora  #$90
          lbne  L0385
-         ldx   #$F000    Address of kernel in RAM
-         ldy   #$0F00    Amount to write
+         ldx   #os9start    Address of kernel in RAM
+         ldy   #os9size     Amount to write
          lda   <DevFd
          os9   I$Write  
          bcs   L0354
@@ -6,14 +6,15 @@
 *
 * The boot code switches into RAM mode, and copies the entire section to
-* $F000 and jumps to $F04F.
-* The 3840 bytes contain a few bytes to do the RAM mode switch, then
+* $EF00 and jumps to $EF4F.
+* The 4096 bytes contain a few bytes to do the RAM mode switch, then
 * immediately after comes the kernel modules; OS9, OS9p2, Init and Boot
 * The rest of the bootstrap is in the OS9Boot file. The disk head at LSN0